@@ -14,7 +14,8 @@ import sys, os
 import pygtk
 pygtk.require('2.0')
 from gtk import gdk
-import gtk.glade
+##import gtk.glade
+import gtk
 import gobject
 
 # keepnote imports
